{% ckan_extends %}

{% block skip %}
    {% if h.status_get_message() %}
        {% asset 'ckanext-status/main' %}
        <p id="status-bar">{{ h.status_get_message() }}</p>
    {% endif %}
    {{ super() }}
{% endblock %}
